var default_nodes_8c =
[
    [ "impl", "structimpl.html", "structimpl" ],
    [ "DEFAULT_CONFIG_AUDIO_SINK_KEY", "default-nodes_8c.html#a842f7ce7f3a7aa9e5bcacc161be704fb", null ],
    [ "DEFAULT_CONFIG_AUDIO_SOURCE_KEY", "default-nodes_8c.html#a93ee4320410c66f9797fcd0d80df669a", null ],
    [ "DEFAULT_CONFIG_VIDEO_SOURCE_KEY", "default-nodes_8c.html#abc7932a3883dc2209c23283d806f62c0", null ],
    [ "NAME", "default-nodes_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
    [ "SAVE_INTERVAL", "default-nodes_8c.html#a499398898d59790b81f8fc343290dbcf", null ],
    [ "SESSION_KEY", "default-nodes_8c.html#a894b84c8f5ff621bf7f7ed71c990b651", null ],
    [ "sm_default_nodes_start", "default-nodes_8c.html#afb83c43b9058b66da4efec655e64f5e2", null ]
];